package com.xperia64.diyedit;

public class WiiSave {

	private byte[] x1; // Wii Savefile
	private byte[] x2; // Miofile
	private int n; // Shelf position 0-77
	// WiiSave constructor
	public WiiSave(byte[] read, byte[] miofile, int mionumber)
	{
		x1=read;
		x2=miofile;
		n=mionumber;
	}
	// Get mio file correctly based on the size of *DATA
	public byte[] getMio()
	{
		switch(x1.length)
		{
		case 4719808:
			return getGame();
		case 591040:
			return getRecord();
		case 1033408:
			return getManga();
		default:
			return new byte[0];
		}
		
	}
	// Sets mio file to position n
	public byte[] setMio()
	{
		return setMio(false);
	}
	// Either sets or deletes mio file at position n
	private byte[] setMio(boolean d)
	{
		switch(x2.length)
		{
		case 65536:
			return setGame(d);
		case 8192:
			return setRecord(d);
		case 14336:
			return setManga(d);
		default:
			return x1;
		}
	}
	// Deletes mio file at position n
	public byte[] deleteMio()
	{
		return setMio(true);
	}
	// Gets mio file from GDATA
	public byte[] getGame()
	{
		double offset=1192;
		byte[] game = new byte[65536];
		offset+=(65536*n);
		if(x1[(int) offset]==0x11&&x1[(int) offset+2]==0x11)
		{
			for(int i = 0; i<65536; i++)
			{
				game[i] = x1[(int) (i+offset)];
			}
			return game;
		}
		return new byte[0];
	}
	// Injects mio file to GDATA
	public byte[] setGame(boolean delete)
	{
		double offset=1192;
		offset+=(65536*n);
		if(delete)
		{
			for(int i = 0; i<65536; i++)
			{
				x1[(int) (i+offset)]=0;
			}
		}else{
			for(int i = 0; i<x2.length; i++)
			{
				x1[(int) (i+offset)]=x2[i];
			}
		}
		return x1;
		
	}
	// Gets mio file from RDATA
	public byte[] getRecord()
	{
		double offset=1192;
		byte[] record = new byte[8192];
		offset+=(8192*n);
		if(x1[(int) offset]==0x11&&x1[(int) offset+2]==0x11)
		{
			for(int i = 0; i<8192; i++)
			{
				record[i] = x1[(int) (i+offset)];
			}
			return record;
		}
		return new byte[0];
	}
	// Injects mio file to RDATA
	public byte[] setRecord(boolean delete)
	{
		double offset=1192;
		offset+=(8192*n);
		if(delete)
		{
			for(int i = 0; i<8192; i++)
			{
				x1[(int) (i+offset)]=0;
			}
		}else{
			for(int i = 0; i<x2.length; i++)
			{
				x1[(int) (i+offset)]=x2[i];
			}
		}
		return x1;
		
	}
	// Gets mio file from MDATA
	public byte[] getManga()
	{
		double offset=1192;
		byte[] manga = new byte[14336];
		offset+=(14336*n);
		if(x1[(int) offset]==0x11&&x1[(int) offset+2]==0x11)
		{
			for(int i = 0; i<14336; i++)
			{
				manga[i] = x1[(int) (i+offset)];
			}
			return manga;
		}
		return new byte[0];
	}
	// Injects mio file to MDATA
	public byte[] setManga(boolean delete)
	{
		double offset=1192;
		offset+=(14336*n);
		if(delete)
		{
			for(int i = 0; i<14336; i++)
			{
				x1[(int) (i+offset)]=0;
			}
		}else{
			for(int i = 0; i<x2.length; i++)
			{
				x1[(int) (i+offset)]=x2[i];
			}
		}
		return x1;
		
	}
}
